@@ -36,10 +36,7 @@
 
 #include "config.h"
 
-#define __STDC_FORMAT_MACROS
-
 #include <rak/error_number.h>
-#include <rak/functional.h>
 
 #include "torrent/exceptions.h"
 #include "torrent/chunk_manager.h"
@@ -67,12 +64,6 @@ struct chunk_list_earliest_modified {
   rak::timer m_time;
 };
 
-struct chunk_list_sort_index {
-  bool operator () (ChunkListNode* node1, ChunkListNode* node2) {
-    return node1->index() < node2->index();
-  }
-};
-
 inline bool
 ChunkList::is_queued(ChunkListNode* node) {
   return std::find(m_queue.begin(), m_queue.end(), node) != m_queue.end();
@@ -86,7 +77,7 @@ ChunkList::has_chunk(size_type index, int prot) const {
 void
 ChunkList::resize(size_type to_size) {
   LT_LOG_THIS(INFO, "Resizing: from:%" PRIu32 " to:%" PRIu32 ".", size(), to_size);
-  
+
   if (!empty())
     throw internal_error("ChunkList::resize(...) called on an non-empty object.");
 
@@ -107,7 +98,7 @@ ChunkList::clear() {
   for (Queue::iterator itr = m_queue.begin(), last = m_queue.end(); itr != last; ++itr) {
     if ((*itr)->references() != 1 || (*itr)->writable() != 1)
       throw internal_error("ChunkList::clear() called but a node in the queue is still referenced.");
-    
+
     (*itr)->dec_rw();
     clear_chunk(*itr);
   }
@@ -293,7 +284,9 @@ ChunkList::sync_chunks(int flags) {
   if (flags & sync_all)
     split = m_queue.begin();
   else
-    split = std::stable_partition(m_queue.begin(), m_queue.end(), rak::not_equal(1, std::mem_fun(&ChunkListNode::writable)));
+    split = std::stable_partition(m_queue.begin(), m_queue.end(), [](ChunkListNode* n) {
+      return 1 != n->writable();
+    });
 
   // Allow a flag that does more culling, so that we only get large
   // continous sections.
