@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -46,14 +46,15 @@
 namespace torrent {
 
 DhtSearch::DhtSearch(const HashString& target, const DhtBucket& contacts)
-  : base_type(dht_compare_closer(m_target = target)),
+  : base_type(dht_compare_closer(target)),
     m_pending(0),
     m_contacted(0),
     m_replied(0),
     m_concurrency(3),
     m_restart(false),
     m_started(false),
-    m_next(end()) {
+    m_next(end()),
+    m_target(target) {
 
   add_contacts(contacts);
 }
@@ -75,7 +76,7 @@ DhtSearch::~DhtSearch() {
 bool
 DhtSearch::add_contact(const HashString& id, const rak::socket_address* sa) {
   DhtNode* n = new DhtNode(id, sa);
-  bool added = insert(std::make_pair(n, this)).second;
+  bool added = emplace(n, this).second;
 
   if (!added)
     delete n;
