@@ -37,9 +37,9 @@
 #ifndef LIBTORRENT_DELEGATOR_H
 #define LIBTORRENT_DELEGATOR_H
 
+#include <functional>
 #include <string>
 #include <vector>
-#include lt_tr1_functional
 
 #include "torrent/data/transfer_list.h"
 
@@ -64,7 +64,7 @@ public:
   TransferList*       transfer_list()                     { return &m_transfers; }
   const TransferList* transfer_list() const               { return &m_transfers; }
 
-  BlockTransfer*     delegate(PeerChunks* peerChunks, int affinity);
+  std::vector<BlockTransfer*> delegate(PeerChunks* peerChunks, uint32_t affinity, uint32_t maxPieces);
 
   bool               get_aggressive()                     { return m_aggressive; }
   void               set_aggressive(bool a)               { m_aggressive = a; }
@@ -72,15 +72,9 @@ public:
   slot_peer_chunk&   slot_chunk_find()                    { return m_slot_chunk_find; }
   slot_size&         slot_chunk_size()                    { return m_slot_chunk_size; }
 
-  // Don't call this from the outside.
-  Block*             delegate_piece(BlockList* c, const PeerInfo* peerInfo);
-  Block*             delegate_aggressive(BlockList* c, uint16_t* overlapped, const PeerInfo* peerInfo);
-
 private:
-  // Start on a new chunk, returns .end() if none possible. bf is
-  // remote peer's bitfield.
-  Block*             new_chunk(PeerChunks* pc, bool highPriority);
-
+  void               delegate_from_blocklist(std::vector<BlockTransfer*> &transfers, uint32_t maxPieces, BlockList* c, PeerInfo* peerInfo);
+  void               delegate_new_chunks(std::vector<BlockTransfer*> &transfers, uint32_t maxPieces, PeerChunks* pc, bool highPriority);
   Block*             delegate_seeder(PeerChunks* peerChunks);
 
   TransferList       m_transfers;
