@@ -36,10 +36,10 @@
 
 #include "config.h"
 
+#include <algorithm>
 #include <cstdio>
 #include <cstring>
 #include <string.h>
-#include <rak/functional.h>
 #include <rak/string_manip.h>
 
 #include "download/download_wrapper.h"
@@ -57,28 +57,14 @@
 
 namespace torrent {
 
-struct download_constructor_is_single_path {
-  bool operator () (Object::map_type::const_reference v) const {
-    return
-      std::strncmp(v.first.c_str(), "name.", sizeof("name.") - 1) == 0 &&
-      v.second.is_string();
-  }
+bool
+download_constructor_is_single_path(Object::map_type::const_reference v) {
+  return v.first.rfind("name.", 0) == 0 && v.second.is_string();
 };
 
-struct download_constructor_is_multi_path {
-  bool operator () (Object::map_type::const_reference v) const {
-    return
-      std::strncmp(v.first.c_str(), "path.", sizeof("path.") - 1) == 0 &&
-      v.second.is_list();
-  }
-};
-
-struct download_constructor_encoding_match :
-    public std::binary_function<const Path&, const char*, bool> {
-
-  bool operator () (const Path& p, const char* enc) {
-    return strcasecmp(p.encoding().c_str(), enc) == 0;
-  }
+bool
+download_constructor_is_multi_path(Object::map_type::const_reference v) {
+  return v.first.rfind("path.", 0) == 0 && v.second.is_list();
 };
 
 void
@@ -109,14 +95,14 @@ DownloadConstructor::parse_name(const Object& b) {
 
   std::list<Path> pathList;
 
-  pathList.push_back(Path());
+  pathList.emplace_back();
   pathList.back().set_encoding(m_defaultEncoding);
   pathList.back().push_back(b.get_key_string("name"));
 
   for (Object::map_const_iterator itr = b.as_map().begin();
-       (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path())) != b.as_map().end();
+       (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path)) != b.as_map().end();
        ++itr) {
-    pathList.push_back(Path());
+    pathList.emplace_back();
     pathList.back().set_encoding(itr->first.substr(sizeof("name.") - 1));
     pathList.back().push_back(itr->second.as_string());
   }
@@ -192,22 +178,25 @@ DownloadConstructor::parse_tracker(const Object& b) {
       // Some torrent makers create empty/invalid 'announce-list'
       // entries while still having valid 'announce'.
       !(announce_list = &b.get_key_list("announce-list"))->empty() &&
-      std::find_if(announce_list->begin(), announce_list->end(), std::mem_fun_ref(&Object::is_list)) != announce_list->end())
-
-    std::for_each(announce_list->begin(), announce_list->end(), rak::make_mem_fun(this, &DownloadConstructor::add_tracker_group));
-
-  else if (b.has_key("announce"))
+      std::find_if(announce_list->begin(), announce_list->end(), std::mem_fun_ref(&Object::is_list)) != announce_list->end()) {
+    for (const auto& group : *announce_list) {
+      add_tracker_group(group);
+    }
+  } else if (b.has_key("announce")) {
     add_tracker_single(b.get_key("announce"), 0);
 
-  else if (!manager->dht_manager()->is_valid() || m_download->info()->is_private())
+  } else if (!manager->dht_manager()->is_valid() || m_download->info()->is_private()) {
     throw bencode_error("Could not find any trackers");
+  }
 
   if (manager->dht_manager()->is_valid() && !m_download->info()->is_private())
     m_download->main()->tracker_list()->insert_url(m_download->main()->tracker_list()->size_group(), "dht://");
 
-  if (manager->dht_manager()->is_valid() && b.has_key_list("nodes"))
-    std::for_each(b.get_key_list("nodes").begin(), b.get_key_list("nodes").end(),
-                  rak::make_mem_fun(this, &DownloadConstructor::add_dht_node));
+  if (manager->dht_manager()->is_valid() && b.has_key_list("nodes")) {
+    for (const auto& node : b.get_key_list("nodes")) {
+      add_dht_node(node);
+    }
+  }
 
   m_download->main()->tracker_list()->randomize_group_entries();
 }
@@ -217,9 +206,9 @@ DownloadConstructor::add_tracker_group(const Object& b) {
   if (!b.is_list())
     throw bencode_error("Tracker group list not a list");
 
-  std::for_each(b.as_list().begin(), b.as_list().end(),
-		rak::bind2nd(rak::make_mem_fun(this, &DownloadConstructor::add_tracker_single),
-			     m_download->main()->tracker_list()->size_group()));
+  for (const auto& tracker : b.as_list()) {
+    add_tracker_single(tracker, m_download->main()->tracker_list()->size_group());
+  }
 }
 
 void
@@ -269,14 +258,14 @@ DownloadConstructor::parse_single_file(const Object& b, uint32_t chunkSize) {
 
   std::list<Path> pathList;
 
-  pathList.push_back(Path());
+  pathList.emplace_back();
   pathList.back().set_encoding(m_defaultEncoding);
   pathList.back().push_back(b.get_key_string("name"));
 
   for (Object::map_const_iterator itr = b.as_map().begin();
-       (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path())) != b.as_map().end();
+       (itr = std::find_if(itr, b.as_map().end(), download_constructor_is_single_path)) != b.as_map().end();
        ++itr) {
-    pathList.push_back(Path());
+    pathList.emplace_back();
     pathList.back().set_encoding(itr->first.substr(sizeof("name.") - 1));
     pathList.back().push_back(itr->second.as_string());
   }
@@ -308,8 +297,8 @@ DownloadConstructor::parse_multi_files(const Object& b, uint32_t chunkSize) {
 
     Object::map_const_iterator itr = listItr->as_map().begin();
     Object::map_const_iterator last = listItr->as_map().end();
-  
-    while ((itr = std::find_if(itr, last, download_constructor_is_multi_path())) != last) {
+
+    while ((itr = std::find_if(itr, last, download_constructor_is_multi_path)) != last) {
       pathList.push_back(create_path(itr->second.as_list(), itr->first.substr(sizeof("path.") - 1)));
       ++itr;
     }
@@ -340,7 +329,7 @@ DownloadConstructor::create_path(const Object::list_type& plist, const std::stri
   if (plist.empty())
     throw input_error("Bad torrent file, \"path\" has zero entries.");
 
-  if (std::find_if(plist.begin(), plist.end(), std::ptr_fun(&DownloadConstructor::is_invalid_path_element)) != plist.end())
+  if (std::any_of(plist.begin(), plist.end(), &DownloadConstructor::is_invalid_path_element))
     throw input_error("Bad torrent file, \"path\" has zero entries or a zero length entry.");
 
   Path p;
@@ -359,8 +348,10 @@ DownloadConstructor::choose_path(std::list<Path>* pathList) {
   EncodingList::const_iterator encodingLast  = m_encodingList->end();
   
   for ( ; encodingFirst != encodingLast; ++encodingFirst) {
-    std::list<Path>::iterator itr = std::find_if(pathFirst, pathLast, rak::bind2nd(download_constructor_encoding_match(), encodingFirst->c_str()));
-    
+    auto itr = std::find_if(pathFirst, pathLast, [encodingFirst](const Path& p) {
+      return strcasecmp(p.encoding().c_str(), encodingFirst->c_str()) == 0;
+    });
+
     if (itr != pathLast)
       pathList->splice(pathFirst, *pathList, itr);
   }
