@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <cstring>
@@ -349,8 +313,7 @@ DownloadMain::receive_tracker_success() {
   if (!info()->is_active())
     return;
 
-  priority_queue_erase(&taskScheduler, &m_taskTrackerRequest);
-  priority_queue_insert(&taskScheduler, &m_taskTrackerRequest, (cachedTime + rak::timer::from_seconds(10)).round_seconds());
+  priority_queue_update(&taskScheduler, &m_taskTrackerRequest, (cachedTime + rak::timer::from_seconds(10)).round_seconds());
 }
 
 void
@@ -365,10 +328,9 @@ DownloadMain::receive_tracker_request() {
   m_tracker_controller->start_requesting();
 }
 
-struct SocketAddressCompact_less {
-  bool operator () (const SocketAddressCompact& a, const SocketAddressCompact& b) const {
-    return (a.addr < b.addr) || ((a.addr == b.addr) && (a.port < b.port));
-  }
+bool
+SocketAddressCompact_less(const SocketAddressCompact& a, const SocketAddressCompact& b) {
+  return (a.addr < b.addr) || ((a.addr == b.addr) && (a.port < b.port));
 };
 
 void
@@ -405,7 +367,7 @@ DownloadMain::do_peer_exchange() {
     const rak::socket_address* sa = rak::socket_address::cast_from(pcb->peer_info()->socket_address());
 
     if (pcb->peer_info()->listen_port() != 0 && sa->family() == rak::socket_address::af_inet)
-      current.push_back(SocketAddressCompact(sa->sa_inet()->address_n(), htons(pcb->peer_info()->listen_port())));
+      current.emplace_back(sa->sa_inet()->address_n(), htons(pcb->peer_info()->listen_port()));
 
     if (!pcb->extensions()->is_remote_supported(ProtocolExtension::UT_PEX))
       continue;
@@ -437,18 +399,16 @@ DownloadMain::do_peer_exchange() {
     pcb->do_peer_exchange();
   }
 
-  std::sort(current.begin(), current.end(), SocketAddressCompact_less());
+  std::sort(current.begin(), current.end(), SocketAddressCompact_less);
 
   ProtocolExtension::PEXList added;
   added.reserve(current.size());
-  std::set_difference(current.begin(), current.end(), m_ut_pex_list.begin(), m_ut_pex_list.end(), 
-                      std::back_inserter(added), SocketAddressCompact_less());
+  std::set_difference(current.begin(), current.end(), m_ut_pex_list.begin(), m_ut_pex_list.end(), std::back_inserter(added), SocketAddressCompact_less);
 
   ProtocolExtension::PEXList removed;
   removed.reserve(m_ut_pex_list.size());
-  std::set_difference(m_ut_pex_list.begin(), m_ut_pex_list.end(), current.begin(), current.end(), 
-                      std::back_inserter(removed), SocketAddressCompact_less());
-    
+  std::set_difference(m_ut_pex_list.begin(), m_ut_pex_list.end(), current.begin(), current.end(), std::back_inserter(removed), SocketAddressCompact_less);
+
   if (current.size() > m_info->max_size_pex_list()) {
     // This test is only correct as long as we have a constant max
     // size.
@@ -461,11 +421,13 @@ DownloadMain::do_peer_exchange() {
     // Create the new m_ut_pex_list by removing any 'removed'
     // addresses from the original list and then adding the new
     // addresses.
-    m_ut_pex_list.erase(std::set_difference(m_ut_pex_list.begin(), m_ut_pex_list.end(), removed.begin(), removed.end(),
-                                            m_ut_pex_list.begin(), SocketAddressCompact_less()), m_ut_pex_list.end());
+    m_ut_pex_list.erase(
+      std::set_difference(
+        m_ut_pex_list.begin(), m_ut_pex_list.end(), removed.begin(), removed.end(), m_ut_pex_list.begin(), SocketAddressCompact_less),
+      m_ut_pex_list.end());
     m_ut_pex_list.insert(m_ut_pex_list.end(), added.begin(), added.end());
 
-    std::sort(m_ut_pex_list.begin(), m_ut_pex_list.end(), SocketAddressCompact_less());
+    std::sort(m_ut_pex_list.begin(), m_ut_pex_list.end(), SocketAddressCompact_less);
 
   } else {
     m_ut_pex_list.swap(current);
