@@ -1,44 +1,7 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DOWNLOAD_MAIN_H
 #define LIBTORRENT_DOWNLOAD_MAIN_H
 
 #include <deque>
-#include <rak/functional.h>
 
 #include "globals.h"
 
@@ -95,7 +58,7 @@ public:
   ChunkList*          chunk_list()                               { return m_chunkList; }
   ChunkSelector*      chunk_selector()                           { return m_chunkSelector; }
   ChunkStatistics*    chunk_statistics()                         { return m_chunkStatistics; }
-  
+
   Delegator*          delegator()                                { return &m_delegator; }
 
   have_queue_type*    have_queue()                               { return &m_haveQueue; }
@@ -129,16 +92,16 @@ public:
   void                setup_delegator();
   void                setup_tracker();
 
-  typedef rak::const_mem_fun1<HandshakeManager, uint32_t, DownloadMain*>                   SlotCountHandshakes;
-  typedef rak::mem_fun1<DownloadWrapper, void, ChunkHandle>                                SlotHashCheckAdd;
+  typedef std::function<uint32_t(DownloadMain*)>                         slot_count_handshakes_type;
+  typedef std::function<void(ChunkHandle)>                               slot_hash_check_add_type;
 
-  typedef rak::mem_fun2<HandshakeManager, void, const rak::socket_address&, DownloadMain*> slot_start_handshake_type;
-  typedef rak::mem_fun1<HandshakeManager, void, DownloadMain*>                             slot_stop_handshakes_type;
+  typedef std::function<void(const rak::socket_address&, DownloadMain*)> slot_start_handshake_type;
+  typedef std::function<void(DownloadMain*)>                             slot_stop_handshakes_type;
 
   void                slot_start_handshake(slot_start_handshake_type s) { m_slotStartHandshake = s; }
   void                slot_stop_handshakes(slot_stop_handshakes_type s) { m_slotStopHandshakes = s; }
-  void                slot_count_handshakes(SlotCountHandshakes s) { m_slotCountHandshakes = s; }
-  void                slot_hash_check_add(SlotHashCheckAdd s)      { m_slotHashCheckAdd = s; }
+  void                slot_count_handshakes(slot_count_handshakes_type s) { m_slotCountHandshakes = s; }
+  void                slot_hash_check_add(slot_hash_check_add_type s)     { m_slotHashCheckAdd = s; }
 
   void                add_peer(const rak::socket_address& sa);
 
@@ -201,8 +164,8 @@ private:
   slot_start_handshake_type m_slotStartHandshake;
   slot_stop_handshakes_type m_slotStopHandshakes;
 
-  SlotCountHandshakes m_slotCountHandshakes;
-  SlotHashCheckAdd    m_slotHashCheckAdd;
+  slot_count_handshakes_type m_slotCountHandshakes;
+  slot_hash_check_add_type   m_slotHashCheckAdd;
 
   rak::priority_item  m_delay_download_done;
   rak::priority_item  m_delay_partially_done;
