@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <iterator>
@@ -56,12 +20,15 @@
 #include "torrent/tracker_controller.h"
 #include "torrent/tracker_list.h"
 #include "torrent/utils/log.h"
+#include "utils/functional.h"
 
 #include "available_list.h"
 #include "chunk_selector.h"
 
 #include "download_wrapper.h"
 
+#define LT_LOG_THIS(log_fmt, ...)                                       \
+  lt_log_print_info(LOG_TORRENT_INFO, this->info(), "download", log_fmt, __VA_ARGS__);
 #define LT_LOG_STORAGE_ERRORS(log_fmt, ...)                             \
   lt_log_print_info(LOG_PROTOCOL_STORAGE_ERRORS, this->info(), "storage_errors", log_fmt, __VA_ARGS__);
 
@@ -117,7 +84,7 @@ DownloadWrapper::initialize(const std::string& hash, const std::string& id) {
 
   file_list()->mutable_data()->mutable_hash().assign(hash.c_str());
 
-  m_main->slot_hash_check_add(rak::make_mem_fun(this, &DownloadWrapper::check_chunk_hash));
+  m_main->slot_hash_check_add([this](torrent::ChunkHandle handle) { return check_chunk_hash(handle); });
 
   // Info hash must be calculate from here on.
   m_hashChecker = new HashTorrent(m_main->chunk_list());
@@ -225,15 +192,14 @@ DownloadWrapper::receive_hash_done(ChunkHandle handle, const char* hash) {
         finished_download();
 
       } else if (was_partial && data()->wanted_chunks() == 0) {
-        priority_queue_erase(&taskScheduler, &m_main->delay_partially_done());
         priority_queue_erase(&taskScheduler, &m_main->delay_partially_restarted());
-        priority_queue_insert(&taskScheduler, &m_main->delay_partially_done(), cachedTime);
+        priority_queue_update(&taskScheduler, &m_main->delay_partially_done(), cachedTime);
       }
     
       if (!m_main->have_queue()->empty() && m_main->have_queue()->front().first >= cachedTime)
-        m_main->have_queue()->push_front(DownloadMain::have_queue_type::value_type(m_main->have_queue()->front().first + 1, handle.index()));
+        m_main->have_queue()->emplace_front(m_main->have_queue()->front().first + 1, handle.index());
       else
-        m_main->have_queue()->push_front(DownloadMain::have_queue_type::value_type(cachedTime, handle.index()));
+        m_main->have_queue()->emplace_front(cachedTime, handle.index());
 
     } else {
       // This needs to ensure the chunk is still valid.
@@ -242,8 +208,8 @@ DownloadWrapper::receive_hash_done(ChunkHandle handle, const char* hash) {
   }
 
     data()->call_chunk_done(handle.object());
-  m_main->chunk_list()->release(&handle);
-}  
+    m_main->chunk_list()->release(&handle);
+}
 
 void
 DownloadWrapper::check_chunk_hash(ChunkHandle handle) {
@@ -271,13 +237,13 @@ DownloadWrapper::receive_tracker_success(AddressList* l) {
   m_main->receive_connect_peers();
   m_main->receive_tracker_success();
 
-  rak::slot_list_call(info()->signal_tracker_success());
+  utils::slot_list_call(info()->signal_tracker_success());
   return inserted;
 }
 
 void
 DownloadWrapper::receive_tracker_failed(const std::string& msg) {
-  rak::slot_list_call(info()->signal_tracker_failed(), msg);
+  utils::slot_list_call(info()->signal_tracker_failed(), msg);
 }
 
 void
@@ -315,18 +281,17 @@ DownloadWrapper::receive_tick(uint32_t ticks) {
   }
 
   DownloadMain::have_queue_type* haveQueue = m_main->have_queue();
-  haveQueue->erase(std::find_if(haveQueue->rbegin(), haveQueue->rend(),
-                                rak::less(cachedTime - rak::timer::from_seconds(600),
-                                             rak::mem_ref(&DownloadMain::have_queue_type::value_type::first))).base(),
-                   haveQueue->end());
+  haveQueue->erase(std::find_if(haveQueue->rbegin(), haveQueue->rend(), [](auto& p) {
+    return (cachedTime - rak::timer::from_seconds(600)) < p.first;
+  }).base(), haveQueue->end());
 
   m_main->receive_connect_peers();
 }
 
 void
 DownloadWrapper::receive_update_priorities() {
-  if (m_main->chunk_selector()->empty())
-    return;
+  LT_LOG_THIS("update priorities: chunks_selected:%" PRIu32 " wanted_chunks:%" PRIu32,
+              m_main->chunk_selector()->size(), data()->wanted_chunks());
 
   data()->mutable_high_priority()->clear();
   data()->mutable_normal_priority()->clear();
@@ -359,13 +324,13 @@ DownloadWrapper::receive_update_priorities() {
   }
 
   bool was_partial = data()->wanted_chunks() != 0;
-
   data()->update_wanted_chunks();
 
   m_main->chunk_selector()->update_priorities();
 
-  std::for_each(m_main->connection_list()->begin(), m_main->connection_list()->end(),
-                rak::on(std::mem_fun(&Peer::m_ptr), std::mem_fun(&PeerConnectionBase::update_interested)));
+  for (const auto& peer : *m_main->connection_list()) {
+    peer->m_ptr()->update_interested();
+  }
 
   // The 'partially_done/restarted' signal only gets triggered when a
   // download is active and not completed.
