@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_MANAGER_H
 #define LIBTORRENT_MANAGER_H
 
@@ -41,6 +5,8 @@
 #include <string>
 #include <rak/priority_queue_default.h>
 
+#include "thread_disk.h"
+#include "thread_main.h"
 #include "net/socket_fd.h"
 
 namespace torrent {
@@ -78,8 +44,10 @@ public:
   ConnectionManager*  connection_manager()                      { return m_connectionManager; }
   DhtManager*         dht_manager()                             { return m_dhtManager; }
   
-  Poll*               poll()                                    { return m_poll; }
-  void                set_poll(Poll* p)                         { m_poll = p; }
+  Poll*               poll()                                    { return m_main_thread_main.poll(); }
+
+  thread_main*        main_thread_main()                        { return &m_main_thread_main; }
+  thread_disk*        main_thread_disk()                        { return &m_main_thread_disk; }
 
   EncodingList*       encoding_list()                           { return &m_encodingList; }
 
@@ -102,7 +70,9 @@ private:
   ClientList*         m_clientList;
   ConnectionManager*  m_connectionManager;
   DhtManager*         m_dhtManager;
-  Poll*               m_poll;
+
+  thread_main         m_main_thread_main;
+  thread_disk         m_main_thread_disk;
 
   EncodingList        m_encodingList;
 
