@@ -38,7 +38,7 @@
 #define LIBTORRENT_NET_PROTOCOL_BUFFER_H
 
 #include <memory>
-#include <inttypes.h>
+#include <cinttypes>
 #include <netinet/in.h>
 
 #include "torrent/exceptions.h"
@@ -50,6 +50,7 @@ class ProtocolBuffer {
 public:
   typedef uint8_t     value_type;
   typedef value_type* iterator;
+  // TODO: Change to 32-bit,
   typedef uint16_t    size_type;
   typedef int16_t     difference_type;
 
