@@ -10,6 +10,7 @@
 #include "torrent/error.h"
 #include "torrent/poll.h"
 #include "torrent/throttle.h"
+#include "torrent/net/socket_address.h"
 #include "torrent/utils/log.h"
 #include "utils/diffie_hellman.h"
 
@@ -24,6 +25,13 @@
   lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt,     \
                m_address.pretty_address_str().c_str(), __VA_ARGS__);
 
+#if DISABLED__USE_EXTRA_DEBUG
+#define LT_LOG_EXTRA_DEBUG_SA(sa, log_fmt, ...)                         \
+  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt, sap_pretty_str(m_address).c_str(), __VA_ARGS__);
+#else
+#define LT_LOG_EXTRA_DEBUG_SA(sa, log_fmt, ...)
+#endif
+
 namespace torrent {
 
 const char* Handshake::m_protocol = "BitTorrent protocol";
@@ -66,7 +74,7 @@ Handshake::Handshake(SocketFd fd, HandshakeManager* m, int encryptionOptions) :
   set_fd(fd);
 
   m_readBuffer.reset();
-  m_writeBuffer.reset();      
+  m_writeBuffer.reset();
 
   m_taskTimeout.clear_time();
   m_taskTimeout.slot() = std::bind(&HandshakeManager::receive_timeout, m, this);
@@ -83,11 +91,11 @@ Handshake::~Handshake() {
 }
 
 void
-Handshake::initialize_incoming(const rak::socket_address& sa) {
+Handshake::initialize_incoming(const sockaddr* sa) {
   m_incoming = true;
-  m_address = sa;
+  m_address = sa_copy(sa);
 
-  if (m_encryption.options() & (ConnectionManager::encryption_allow_incoming | ConnectionManager::encryption_require)) 
+  if (m_encryption.options() & (ConnectionManager::encryption_allow_incoming | ConnectionManager::encryption_require))
     m_state = READ_ENC_KEY;
   else
     m_state = READ_INFO;
@@ -101,16 +109,16 @@ Handshake::initialize_incoming(const rak::socket_address& sa) {
 }
 
 void
-Handshake::initialize_outgoing(const rak::socket_address& sa, DownloadMain* d, PeerInfo* peerInfo) {
+Handshake::initialize_outgoing(const sockaddr* sa, DownloadMain* d, PeerInfo* peerInfo) {
   m_download = d;
 
   m_peerInfo = peerInfo;
   m_peerInfo->set_flags(PeerInfo::flag_handshake);
 
   m_incoming = false;
-  m_address = sa;
+  m_address = sa_copy(sa);
 
-  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
+  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.get());
 
   m_state = CONNECTING;
 
@@ -202,7 +210,7 @@ bool
 Handshake::read_proxy_connect() {
   // Being greedy for now.
   m_readBuffer.move_end(read_unthrottled(m_readBuffer.end(), 512));
-  
+
   const char* pattern = "\r\n\r\n";
   const unsigned int patternLength = 4;
 
@@ -227,7 +235,7 @@ Handshake::read_encryption_key() {
   if (m_incoming) {
     if (m_readBuffer.remaining() < 20)
       m_readBuffer.move_end(read_unthrottled(m_readBuffer.end(), 20 - m_readBuffer.remaining()));
-  
+
     if (m_readBuffer.remaining() < 20)
       return false;
 
@@ -318,6 +326,8 @@ Handshake::read_encryption_sync() {
 
 bool
 Handshake::read_encryption_skey() {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_encryption_skey", 0)
+
   if (!fill_read_buffer(20))
     return false;
 
@@ -327,7 +337,7 @@ Handshake::read_encryption_skey() {
 
   validate_download();
 
-  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
+  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.get());
 
   m_encryption.initialize_encrypt(m_download->info()->hash().c_str(), m_incoming);
   m_encryption.initialize_decrypt(m_download->info()->hash().c_str(), m_incoming);
@@ -344,6 +354,8 @@ Handshake::read_encryption_skey() {
 
 bool
 Handshake::read_encryption_negotiation() {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_encryption_negotiation", 0)
+
   if (!fill_read_buffer(enc_negotiation_size))
     return false;
 
@@ -421,6 +433,8 @@ Handshake::read_negotiation_reply() {
     return true;
   }
 
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_negotiation_reply", 0)
+
   if (!fill_read_buffer(2))
     return false;
 
@@ -439,6 +453,8 @@ Handshake::read_negotiation_reply() {
 
 bool
 Handshake::read_info() {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_info", 0)
+
   fill_read_buffer(handshake_size);
 
   // Check the first byte as early as possible so we can
@@ -474,7 +490,7 @@ Handshake::read_info() {
 
     validate_download();
 
-    std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
+    std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.get());
 
     prepare_handshake();
 
@@ -491,6 +507,8 @@ Handshake::read_info() {
 
 bool
 Handshake::read_peer() {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_peer", 0)
+
   if (!fill_read_buffer(20))
     return false;
 
@@ -531,6 +549,8 @@ Handshake::read_peer() {
 
 bool
 Handshake::read_bitfield() {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_bitfield: size:%" PRIu32, m_bitfield.size_bytes());
+
   if (m_readPos < m_bitfield.size_bytes()) {
     uint32_t length = read_unthrottled(m_bitfield.begin() + m_readPos, m_bitfield.size_bytes() - m_readPos);
 
@@ -566,6 +586,8 @@ Handshake::read_extension() {
       throw handshake_error(ConnectionManager::handshake_failed, e_handshake_invalid_value);
   }
 
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_extension", 0)
+
   if (!fill_read_buffer(m_readBuffer.peek_32() + 4))
     return false;
 
@@ -599,6 +621,8 @@ Handshake::read_port() {
       throw handshake_error(ConnectionManager::handshake_failed, e_handshake_invalid_value);
   }
 
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "read_port", 0)
+
   if (!fill_read_buffer(m_readBuffer.peek_32() + 4))
     return false;
 
@@ -606,7 +630,7 @@ Handshake::read_port() {
   m_readBuffer.read_8();
 
   if (length == 2)
-    manager->dht_manager()->add_node(m_address.c_sockaddr(), m_readBuffer.peek_16());
+    manager->dht_manager()->add_node(m_address.get(), m_readBuffer.peek_16());
 
   m_readBuffer.consume(length);
   return true;
@@ -684,6 +708,8 @@ restart:
 
     case READ_ENC_PAD:
       if (m_readPos) {
+        LT_LOG_EXTRA_DEBUG_SA(m_address, "event_read : READ_ENC_PAD : m_readPos:%" PRIu32, m_readPos)
+
         // Read padC + lenIA or padD; pad length in m_readPos.
         if (!fill_read_buffer(m_readPos + (m_incoming ? 2 : 0)))
           // This can be improved (consume as much as was read)
@@ -700,6 +726,8 @@ restart:
         goto restart;
 
     case READ_ENC_IA:
+      LT_LOG_EXTRA_DEBUG_SA(m_address, "event_read : READ_ENC_IA", 0)
+
       // Just read (and automatically decrypt) the initial payload
       // and leave it in the buffer for READ_INFO later.
       if (m_encryption.length_ia() > 0 && !fill_read_buffer(m_encryption.length_ia()))
@@ -741,6 +769,11 @@ restart:
         break;
       }
 
+      LT_LOG_EXTRA_DEBUG_SA(m_address, "event_read : READ_MESSAGE", 0);
+
+      if (m_readBuffer.reserved_left() < 5)
+        m_readBuffer.move_unused();
+
       fill_read_buffer(5);
 
       // Received a keep-alive message which means we won't be
@@ -836,6 +869,9 @@ restart:
 
 bool
 Handshake::fill_read_buffer(int size) {
+  LT_LOG_EXTRA_DEBUG_SA(m_address, "fill_read_buffer : size:%i remaining:%" PRIu16 " reserved_left:%" PRIu16,
+                        size, m_readBuffer.remaining(), m_readBuffer.reserved_left())
+
   if (m_readBuffer.remaining() < size) {
     if (size - m_readBuffer.remaining() > m_readBuffer.reserved_left())
       throw internal_error("Handshake::fill_read_buffer(...) Buffer overflow.");
@@ -872,7 +908,7 @@ Handshake::event_write() {
 
       if (m_encryption.options() & ConnectionManager::encryption_use_proxy) {
         prepare_proxy_connect();
-        
+
         m_state = PROXY_CONNECT;
         break;
       }
@@ -943,11 +979,8 @@ Handshake::event_write() {
 
 void
 Handshake::prepare_proxy_connect() {
-  char buf[256];
-  m_address.address_c_str(buf, 256);  
-
   int advance = snprintf((char*)m_writeBuffer.position(), m_writeBuffer.reserved_left(),
-                         "CONNECT %s:%hu HTTP/1.0\r\n\r\n", buf, m_address.port());
+                         "CONNECT %s:%hu HTTP/1.0\r\n\r\n", sap_addr_str(m_address).c_str(), sap_port(m_address));
 
   if (advance == -1 || advance > m_writeBuffer.reserved_left())
     throw internal_error("Handshake::prepare_proxy_connect() snprintf failed.");
@@ -1035,7 +1068,7 @@ Handshake::prepare_peer_info() {
     if (!m_incoming)
       throw internal_error("Handshake::prepare_peer_info() !m_incoming.");
 
-    m_peerInfo = m_download->peer_list()->connected(m_address.c_sockaddr(), PeerList::connect_incoming);
+    m_peerInfo = m_download->peer_list()->connected(m_address.get(), PeerList::connect_incoming);
 
     if (m_peerInfo == NULL)
       throw handshake_error(ConnectionManager::handshake_failed, e_handshake_no_peer_info);
