@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_HANDSHAKE_H
 #define LIBTORRENT_HANDSHAKE_H
 
@@ -57,6 +21,7 @@ public:
   static const uint32_t part1_size     = 20 + 28;
   static const uint32_t part2_size     = 20;
   static const uint32_t handshake_size = part1_size + part2_size;
+  static const uint32_t read_message_size = 2 * 5;
 
   static const uint32_t protocol_bitfield  = 5;
   static const uint32_t protocol_port      = 9;
@@ -66,7 +31,7 @@ public:
   static const uint32_t enc_pad_size         = 512;
   static const uint32_t enc_pad_read_size    = 96 + enc_pad_size + 20;
 
-  static const uint32_t buffer_size = enc_pad_read_size + 20 + enc_negotiation_size + enc_pad_size + 2 + handshake_size + 5;
+  static const uint32_t buffer_size = enc_pad_read_size + 20 + enc_negotiation_size + enc_pad_size + 2 + handshake_size + read_message_size;
 
   typedef ProtocolBuffer<buffer_size> Buffer;
 
@@ -102,19 +67,19 @@ public:
 
   State               state() const                 { return m_state; }
 
-  void                initialize_incoming(const rak::socket_address& sa);
-  void                initialize_outgoing(const rak::socket_address& sa, DownloadMain* d, PeerInfo* peerInfo);
-  
+  void                initialize_incoming(const sockaddr* sa);
+  void                initialize_outgoing(const sockaddr* sa, DownloadMain* d, PeerInfo* peerInfo);
+
   PeerInfo*           peer_info()                   { return m_peerInfo; }
   const PeerInfo*     peer_info() const             { return m_peerInfo; }
 
   void                set_peer_info(PeerInfo* p)    { m_peerInfo = p; }
 
-  const rak::socket_address* socket_address() const { return &m_address; }
+  const sockaddr*     socket_address() const        { return m_address.get(); }
 
   DownloadMain*       download()                    { return m_download; }
   Bitfield*           bitfield()                    { return &m_bitfield; }
-  
+
   void                deactivate_connection();
   void                release_connection();
   void                destroy_connection();
@@ -136,7 +101,7 @@ public:
 protected:
   Handshake(const Handshake&);
   void operator = (const Handshake&);
-  
+
   void                read_done();
   void                write_done();
 
@@ -195,7 +160,7 @@ protected:
 
   bool                m_incoming;
 
-  rak::socket_address m_address;
+  c_sa_unique_ptr     m_address;
   char                m_options[8];
 
   HandshakeEncryption m_encryption;
