@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <rak/socket_address.h>
@@ -43,6 +7,7 @@
 #include "download/download_main.h"
 #include "torrent/connection_manager.h"
 #include "torrent/download_info.h"
+#include "torrent/net/socket_address.h"
 #include "torrent/peer/peer_info.h"
 #include "torrent/peer/client_list.h"
 #include "torrent/peer/connection_list.h"
@@ -54,32 +19,31 @@
 
 #include "manager.h"
 
-#define LT_LOG_SA(log_level, sa, log_fmt, ...)                          \
-  lt_log_print(LOG_CONNECTION_##log_level, "handshake_manager->%s: " log_fmt, (sa)->address_str().c_str(), __VA_ARGS__);
-#define LT_LOG_SA_C(log_level, sa, log_fmt, ...)                        \
-  lt_log_print(LOG_CONNECTION_##log_level, "handshake_manager->%s: " log_fmt, \
+#define LT_LOG_SA(sa, log_fmt, ...)                                     \
+  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake_manager->%s: " log_fmt, (sa)->address_str().c_str(), __VA_ARGS__);
+#define LT_LOG_SAP(sa, log_fmt, ...)                                 \
+  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake_manager->%s: " log_fmt, sap_addr_str(sa).c_str(), __VA_ARGS__);
+#define LT_LOG_SA_C(sa, log_fmt, ...)                                   \
+  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake_manager->%s: " log_fmt, \
                reinterpret_cast<const rak::socket_address*>(sa)->address_str().c_str(), __VA_ARGS__);
 
 namespace torrent {
 
 ProtocolExtension HandshakeManager::DefaultExtensions = ProtocolExtension::make_default();
 
-inline void
-handshake_manager_delete_handshake(Handshake* h) {
-  h->deactivate_connection();
-  h->destroy_connection();
-
-  delete h;
-}
-
 HandshakeManager::size_type
 HandshakeManager::size_info(DownloadMain* info) const {
-  return std::count_if(base_type::begin(), base_type::end(), rak::equal(info, std::mem_fun(&Handshake::download)));
+  return std::count_if(base_type::begin(), base_type::end(), [info](Handshake* h) { return info == h->download(); });
 }
 
 void
 HandshakeManager::clear() {
-  std::for_each(base_type::begin(), base_type::end(), std::ptr_fun(&handshake_manager_delete_handshake));
+  for (auto h : *this) {
+    h->deactivate_connection();
+    h->destroy_connection();
+
+    delete h;
+  };
   base_type::clear();
 }
 
@@ -93,22 +57,25 @@ HandshakeManager::erase(Handshake* handshake) {
   base_type::erase(itr);
 }
 
-struct handshake_manager_equal : std::binary_function<const rak::socket_address*, const Handshake*, bool> {
-  bool operator () (const rak::socket_address* sa1, const Handshake* p2) const {
-    return p2->peer_info() != NULL && *sa1 == *rak::socket_address::cast_from(p2->peer_info()->socket_address());
-  }
-};
-
 bool
 HandshakeManager::find(const rak::socket_address& sa) {
-  return std::find_if(base_type::begin(), base_type::end(), std::bind1st(handshake_manager_equal(), &sa)) != base_type::end();
+  return std::any_of(base_type::begin(), base_type::end(), [&sa](auto p2) {
+    return p2->peer_info() && sa == *rak::socket_address::cast_from(p2->peer_info()->socket_address());
+  });
 }
 
 void
 HandshakeManager::erase_download(DownloadMain* info) {
-  iterator split = std::partition(base_type::begin(), base_type::end(), rak::not_equal(info, std::mem_fun(&Handshake::download)));
+  auto split = std::partition(base_type::begin(), base_type::end(), [info](Handshake* h) {
+    return info != h->download();
+  });
 
-  std::for_each(split, base_type::end(), std::ptr_fun(&handshake_manager_delete_handshake));
+  std::for_each(split, base_type::end(), [](auto h) {
+    h->deactivate_connection();
+    h->destroy_connection();
+
+    delete h;
+  });
   base_type::erase(split, base_type::end());
 }
 
@@ -121,16 +88,16 @@ HandshakeManager::add_incoming(SocketFd fd, const rak::socket_address& sa) {
     return;
   }
 
-  LT_LOG_SA(INFO, &sa, "Adding incoming connection: fd:%i.", fd.get_fd());
+  LT_LOG_SA(&sa, "accepted incoming connection: fd:%i", fd.get_fd());
 
   manager->connection_manager()->inc_socket_count();
 
   Handshake* h = new Handshake(fd, this, manager->connection_manager()->encryption_options());
-  h->initialize_incoming(sa);
+  h->initialize_incoming(sa.c_sockaddr());
 
   base_type::push_back(h);
 }
-  
+
 void
 HandshakeManager::add_outgoing(const rak::socket_address& sa, DownloadMain* download) {
   if (!manager->connection_manager()->can_connect() ||
@@ -141,10 +108,10 @@ HandshakeManager::add_outgoing(const rak::socket_address& sa, DownloadMain* down
 }
 
 void
-HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* download, int encryptionOptions) {
+HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* download, int encryption_options) {
   int connection_options = PeerList::connect_keep_handshakes;
 
-  if (!(encryptionOptions & ConnectionManager::encryption_retrying))
+  if (!(encryption_options & ConnectionManager::encryption_retrying))
     connection_options |= PeerList::connect_filter_recent;
 
   PeerInfo* peerInfo = download->peer_list()->connected(sa.c_sockaddr(), connection_options);
@@ -158,7 +125,7 @@ HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* d
 
   if (rak::socket_address::cast_from(manager->connection_manager()->proxy_address())->is_valid()) {
     connectAddress = rak::socket_address::cast_from(manager->connection_manager()->proxy_address());
-    encryptionOptions |= ConnectionManager::encryption_use_proxy;
+    encryption_options |= ConnectionManager::encryption_use_proxy;
   }
 
   if (!fd.open_stream() ||
@@ -175,18 +142,18 @@ HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* d
 
   int message;
 
-  if (encryptionOptions & ConnectionManager::encryption_use_proxy)
+  if (encryption_options & ConnectionManager::encryption_use_proxy)
     message = ConnectionManager::handshake_outgoing_proxy;
-  else if (encryptionOptions & (ConnectionManager::encryption_try_outgoing | ConnectionManager::encryption_require))
+  else if (encryption_options & (ConnectionManager::encryption_try_outgoing | ConnectionManager::encryption_require))
     message = ConnectionManager::handshake_outgoing_encrypted;
   else
     message = ConnectionManager::handshake_outgoing;
 
-  LT_LOG_SA(INFO, &sa, "Adding outcoming connection: encryption:%x message:%x.", encryptionOptions, message);
+  LT_LOG_SA(&sa, "created outgoing connection: fd:%i encryption:%x message:%x", fd.get_fd(), encryption_options, message);
   manager->connection_manager()->inc_socket_count();
 
-  Handshake* handshake = new Handshake(fd, this, encryptionOptions);
-  handshake->initialize_outgoing(sa, download, peerInfo);
+  Handshake* handshake = new Handshake(fd, this, encryption_options);
+  handshake->initialize_outgoing(sa.c_sockaddr(), download, peerInfo);
 
   base_type::push_back(handshake);
 }
@@ -202,6 +169,8 @@ HandshakeManager::receive_succeeded(Handshake* handshake) {
   DownloadMain* download = handshake->download();
   PeerConnectionBase* pcb;
 
+  auto peer_type = handshake->bitfield()->is_all_set() ? "seed" : "leech";
+
   if (download->info()->is_active() &&
       download->connection_list()->want_connection(handshake->peer_info(), handshake->bitfield()) &&
 
@@ -210,12 +179,13 @@ HandshakeManager::receive_succeeded(Handshake* handshake) {
                                                  handshake->bitfield(),
                                                  handshake->encryption()->info(),
                                                  handshake->extensions())) != NULL) {
-    
-    manager->client_list()->retrieve_id(&handshake->peer_info()->mutable_client_info(), handshake->peer_info()->id());
-    LT_LOG_SA_C(INFO, handshake->peer_info()->socket_address(), "Handshake success.", 0);
 
+    manager->client_list()->retrieve_id(&handshake->peer_info()->mutable_client_info(), handshake->peer_info()->id());
     pcb->peer_chunks()->set_have_timer(handshake->initialized_time());
 
+    LT_LOG_SA_C(handshake->peer_info()->socket_address(), "handshake success: type:%s id:%s",
+                peer_type, hash_string_to_html_str(handshake->peer_info()->id()).c_str());
+
     if (handshake->unread_size() != 0) {
       if (handshake->unread_size() > PeerConnectionBase::ProtocolRead::buffer_size)
         throw internal_error("HandshakeManager::receive_succeeded(...) Unread data won't fit PCB's read buffer.");
@@ -236,7 +206,9 @@ HandshakeManager::receive_succeeded(Handshake* handshake) {
     else
       reason = e_handshake_duplicate;
 
-    LT_LOG_SA_C(INFO, handshake->peer_info()->socket_address(), "Handshake dropped: %s.", strerror(reason));
+    LT_LOG_SA_C(handshake->peer_info()->socket_address(), "handshake dropped: type:%s id:%s reason:'%s'",
+                peer_type, hash_string_to_html_str(handshake->peer_info()->id()).c_str(), strerror(reason));
+
     handshake->destroy_connection();
   }
 
@@ -248,22 +220,25 @@ HandshakeManager::receive_failed(Handshake* handshake, int message, int error) {
   if (!handshake->is_active())
     throw internal_error("HandshakeManager::receive_failed(...) called on an inactive handshake.");
 
-  const rak::socket_address* sa = handshake->socket_address();
+  auto sa = sa_copy(handshake->socket_address());
 
   erase(handshake);
   handshake->deactivate_connection();
   handshake->destroy_connection();
 
-  LT_LOG_SA(INFO, sa, "Received error: message:%x %s.", message, strerror(error));
+  LT_LOG_SAP(sa, "Received error: message:%x %s.", message, strerror(error));
 
   if (handshake->encryption()->should_retry()) {
     int retry_options = handshake->retry_options() | ConnectionManager::encryption_retrying;
     DownloadMain* download = handshake->download();
 
-    LT_LOG_SA(INFO, sa, "Retrying %s.",
+    LT_LOG_SAP(sa, "Retrying %s.",
               retry_options & ConnectionManager::encryption_try_outgoing ? "encrypted" : "plaintext");
 
-    create_outgoing(*sa, download, retry_options);
+    rak::socket_address sa_copy;
+    sa_copy.copy_sockaddr(sa.get());
+
+    create_outgoing(sa_copy, download, retry_options);
   }
 
   delete handshake;
@@ -289,7 +264,7 @@ HandshakeManager::setup_socket(SocketFd fd) {
 
   if (m->send_buffer_size() != 0 && !fd.set_send_buffer_size(m->send_buffer_size()))
     return false;
-    
+
   if (m->receive_buffer_size() != 0 && !fd.set_receive_buffer_size(m->receive_buffer_size()))
     return false;
 
