@@ -36,12 +36,9 @@
 
 #include "config.h"
 
-#define __STDC_FORMAT_MACROS
-
 #include <cstdio>
 #include <fcntl.h>
 #include <rak/error_number.h>
-#include <rak/functional.h>
 #include <rak/string_manip.h>
 
 #include "data/chunk_iterator.h"
@@ -970,24 +967,25 @@ PeerConnectionBase::try_request_pieces() {
 
   while (request_list()->queued_size() < pipeSize && m_up->can_write_request()) {
 
-    // Delegator should return a vector of pieces, and it should be
-    // passed the number of pieces it should delegate. Try to ensure
-    // it receives large enough request to fill a whole chunk if the
-    // peer is fast enough.
+    // It should get the right number the first time around, but loop just to be sure
+    int maxRequests = m_up->max_write_request();
+    int maxQueued = pipeSize - request_list()->queued_size();
+    int maxPieces = std::max(std::min(maxRequests, maxQueued), 1);
+    
+    std::vector<const Piece*> pieces = request_list()->delegate(maxPieces);
+    if (pieces.empty()) {
+      return false;
+    }
 
-    const Piece* p = request_list()->delegate();
+    for (auto& p : pieces) {
+      if (!m_download->file_list()->is_valid_piece(*p) || !m_peerChunks.bitfield()->get(p->index()))
+        throw internal_error("PeerConnectionBase::try_request_pieces() tried to use an invalid piece.");
 
-    if (p == NULL)
-      break;
-
-    if (!m_download->file_list()->is_valid_piece(*p) || !m_peerChunks.bitfield()->get(p->index()))
-      throw internal_error("PeerConnectionBase::try_request_pieces() tried to use an invalid piece.");
-
-    m_up->write_request(*p);
-
-    LT_LOG_PIECE_EVENTS("(down) requesting %" PRIu32 " %" PRIu32 " %" PRIu32,
-                        p->index(), p->offset(), p->length());
-    success = true;
+      m_up->write_request(*p);
+      LT_LOG_PIECE_EVENTS("(down) requesting %" PRIu32 " %" PRIu32 " %" PRIu32,
+                          p->index(), p->offset(), p->length());
+      success = true;
+    }
   }
 
   return success;
