@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,9 +37,13 @@
 #ifndef LIBTORRENT_COMMON_H
 #define LIBTORRENT_COMMON_H
 
-#include <inttypes.h>
+#include <cinttypes>
+#include <cstddef>
 
 struct sockaddr;
+struct sockaddr_in;
+struct sockaddr_in6;
+struct sockaddr_un;
 
 namespace torrent {
 
@@ -67,6 +71,8 @@ class ClientInfo;
 class ClientList;
 class ConnectionList;
 class ConnectionManager;
+class DhtManager;
+class DhtRouter;
 class Download;
 class DownloadMain;
 class DownloadWrapper;
@@ -87,12 +93,12 @@ class PeerInfo;
 class PeerList;
 class Piece;
 class Poll;
+class ProtocolExtension;
 class Rate;
 class SocketSet;
+class Throttle;
 class Tracker;
-class TrackerBase;
 class TrackerList;
-class TrackerManager;
 class TransferList;
 
 // This should only need to be set when compiling libtorrent.
