@@ -38,7 +38,6 @@
 
 #include <algorithm>
 #include <functional>
-#include <rak/functional.h>
 
 #include "peer/peer_info.h"
 #include "protocol/peer_connection_base.h"
@@ -141,10 +140,12 @@ Block::erase(BlockTransfer* transfer) {
       transfer_list_type::iterator first = std::find_if(m_transfers.begin(), m_transfers.end(), std::not1(std::mem_fun(&BlockTransfer::is_leader)));
       transfer_list_type::iterator last = std::stable_partition(first, m_transfers.end(), std::mem_fun(&BlockTransfer::is_not_leader));
 
-      transfer_list_type::iterator newLeader = std::max_element(first, last, rak::less2(std::mem_fun(&BlockTransfer::position), std::mem_fun(&BlockTransfer::position)));
+      transfer_list_type::iterator new_leader = std::max_element(first, last, [](BlockTransfer* t1, BlockTransfer* t2) {
+        return t1->position() < t2->position();
+      });
 
-      if (newLeader != last) {
-        m_leader = *newLeader;
+      if (new_leader != last) {
+        m_leader = *new_leader;
         m_leader->set_state(BlockTransfer::STATE_LEADER);
       } else {
         m_leader = NULL;
@@ -381,7 +382,7 @@ Block::remove_non_leader_transfers() {
 
 BlockTransfer*
 Block::find_queued(const PeerInfo* p) {
-  transfer_list_type::iterator itr = std::find_if(m_queued.begin(), m_queued.end(), rak::equal(p, std::mem_fun(&BlockTransfer::peer_info)));
+  auto itr = std::find_if(m_queued.begin(), m_queued.end(), [p](BlockTransfer* t) { return p == t->peer_info(); });
 
   if (itr == m_queued.end())
     return NULL;
@@ -391,7 +392,7 @@ Block::find_queued(const PeerInfo* p) {
 
 const BlockTransfer*
 Block::find_queued(const PeerInfo* p) const {
-  transfer_list_type::const_iterator itr = std::find_if(m_queued.begin(), m_queued.end(), rak::equal(p, std::mem_fun(&BlockTransfer::peer_info)));
+  auto itr = std::find_if(m_queued.begin(), m_queued.end(), [p](BlockTransfer* t) { return p == t->peer_info(); });
 
   if (itr == m_queued.end())
     return NULL;
@@ -401,7 +402,7 @@ Block::find_queued(const PeerInfo* p) const {
 
 BlockTransfer*
 Block::find_transfer(const PeerInfo* p) {
-  transfer_list_type::iterator itr = std::find_if(m_transfers.begin(), m_transfers.end(), rak::equal(p, std::mem_fun(&BlockTransfer::peer_info)));
+  auto itr = std::find_if(m_transfers.begin(), m_transfers.end(), [p](BlockTransfer* t) { return p == t->peer_info(); });
 
   if (itr == m_transfers.end())
     return NULL;
@@ -411,7 +412,7 @@ Block::find_transfer(const PeerInfo* p) {
 
 const BlockTransfer*
 Block::find_transfer(const PeerInfo* p) const {
-  transfer_list_type::const_iterator itr = std::find_if(m_transfers.begin(), m_transfers.end(), rak::equal(p, std::mem_fun(&BlockTransfer::peer_info)));
+  auto itr = std::find_if(m_transfers.begin(), m_transfers.end(), [p](BlockTransfer* t) { return p == t->peer_info(); });
 
   if (itr == m_transfers.end())
     return NULL;
