@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -85,25 +85,25 @@ private:
   BlockFailed(const BlockFailed&);
   void operator = (const BlockFailed&);
 
-  static void         delete_entry(const reference e)                         { delete [] e.first; }
-  static bool         compare_entries(const reference e1, const reference e2) { return e1.second < e2.second; }
+  static void         delete_entry(value_type e)                    { delete [] e.first; }
+  static bool         compare_entries(value_type e1, value_type e2) { return e1.second < e2.second; }
 
   size_type           m_current;
 };
 
 inline
 BlockFailed::~BlockFailed() {
-  std::for_each(begin(), end(), std::ptr_fun(&BlockFailed::delete_entry));
+  std::for_each(begin(), end(), &BlockFailed::delete_entry);
 }
 
 inline BlockFailed::iterator
 BlockFailed::max_element() {
-  return std::max_element(begin(), end(), std::ptr_fun(&BlockFailed::compare_entries));
+  return std::max_element(begin(), end(), &BlockFailed::compare_entries);
 }
 
 inline BlockFailed::reverse_iterator
 BlockFailed::reverse_max_element() {
-  return std::max_element(rbegin(), rend(), std::ptr_fun(&BlockFailed::compare_entries));
+  return std::max_element(rbegin(), rend(), &BlockFailed::compare_entries);
 }
 
 }
