@@ -1,47 +1,9 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
+#include <cstdlib>
 #include <functional>
 #include <numeric>
-#include <cstdlib>
-#include <tr1/functional>
-#include <rak/functional.h>
 
 #include "protocol/peer_connection_base.h"
 #include "torrent/download/group_entry.h"
@@ -51,10 +13,15 @@
 
 #include "choke_queue.h"
 
+// TODO: Add a different logging category.
+#define LT_LOG_THIS(log_fmt, ...)                                       \
+  lt_log_print_subsystem(LOG_TORRENT_INFO, "choke_queue", log_fmt, __VA_ARGS__);
+
 namespace torrent {
 
-struct choke_manager_less {
-  bool operator () (choke_queue::value_type v1, choke_queue::value_type v2) const { return v1.weight < v2.weight; }
+bool
+choke_manager_less(choke_queue::value_type v1, choke_queue::value_type v2) {
+  return v1.weight < v2.weight;
 };
 
 static inline bool
@@ -104,10 +71,10 @@ choke_queue::prepare_weights(group_stats gs) {
 
   for (group_container_type::iterator itr = m_group_container.begin(), last = m_group_container.end(); itr != last; itr++) {
     m_heuristics_list[m_heuristics].slot_choke_weight((*itr)->mutable_unchoked()->begin(), (*itr)->mutable_unchoked()->end());
-    std::sort((*itr)->mutable_unchoked()->begin(), (*itr)->mutable_unchoked()->end(), choke_manager_less());
+    std::sort((*itr)->mutable_unchoked()->begin(), (*itr)->mutable_unchoked()->end(), choke_manager_less);
 
     m_heuristics_list[m_heuristics].slot_unchoke_weight((*itr)->mutable_queued()->begin(), (*itr)->mutable_queued()->end());
-    std::sort((*itr)->mutable_queued()->begin(), (*itr)->mutable_queued()->end(), choke_manager_less());
+    std::sort((*itr)->mutable_queued()->begin(), (*itr)->mutable_queued()->end(), choke_manager_less);
 
     // Aggregate the statistics... Remember to update them after
     // optimistic/pessimistic unchokes.
@@ -194,6 +161,9 @@ choke_queue::rebuild_containers(container_type* queued, container_type* unchoked
 
 void
 choke_queue::balance() {
+  LT_LOG_THIS("balancing queue: heuristics:%i currently_unchoked:%" PRIu32 " max_unchoked:%" PRIu32,
+              m_heuristics, m_currently_unchoked, m_maxUnchoked)
+
   // Return if no balancing is needed. Don't return if is_unlimited()
   // as we might have just changed the value and have interested that
   // can be unchoked.
@@ -217,6 +187,9 @@ choke_queue::balance() {
 
   // If we have more unchoked than max global slots allow for,
   // 'can_unchoke' will be negative.
+  //
+  // Throws std::bad_function_call if 'set_slot_can_unchoke' is not
+  // set.
   int can_unchoke = m_slotCanUnchoke();
   int max_unchoked = std::min(m_maxUnchoked, (uint32_t)(1 << 20));
 
@@ -241,17 +214,17 @@ choke_queue::balance() {
   if (result != 0)
     m_slotUnchoke(result);
 
-  lt_log_print(LOG_PEER_DEBUG, "Called balance; adjust:%i can_unchoke:%i queued:%u unchoked:%u result:%i.",
-               adjust, can_unchoke, (unsigned)queued.size(), (unsigned)unchoked.size(), result);
+  LT_LOG_THIS("balanced queue: adjust:%i can_unchoke:%i queued:%" PRIu32 " unchoked:%" PRIu32 " result:%i",
+               adjust, can_unchoke, queued.size(), unchoked.size(), result);
 }
 
 void
 choke_queue::balance_entry(group_entry* entry) {
   m_heuristics_list[m_heuristics].slot_choke_weight(entry->mutable_unchoked()->begin(), entry->mutable_unchoked()->end());
-  std::sort(entry->mutable_unchoked()->begin(), entry->mutable_unchoked()->end(), choke_manager_less());
+  std::sort(entry->mutable_unchoked()->begin(), entry->mutable_unchoked()->end(), choke_manager_less);
 
   m_heuristics_list[m_heuristics].slot_unchoke_weight(entry->mutable_queued()->begin(), entry->mutable_queued()->end());
-  std::sort(entry->mutable_queued()->begin(), entry->mutable_queued()->end(), choke_manager_less());
+  std::sort(entry->mutable_queued()->begin(), entry->mutable_queued()->end(), choke_manager_less);
 
   int count = 0;
   unsigned int min_slots = std::min(entry->min_slots(), entry->max_slots());
@@ -455,7 +428,7 @@ void
 choke_manager_allocate_slots(choke_queue::iterator first, choke_queue::iterator last,
                              uint32_t max, uint32_t* weights, choke_queue::target_type* target) {
   // Sorting the connections from the lowest to highest value.
-  // TODO:  std::sort(first, last, choke_manager_less());
+  // TODO:  std::sort(first, last, choke_manager_less);
 
   // 'weightTotal' only contains the weight of targets that have
   // connections to unchoke. When all connections are in a group are
@@ -467,9 +440,9 @@ choke_manager_allocate_slots(choke_queue::iterator first, choke_queue::iterator
 
   for (uint32_t i = 0; i < choke_queue::order_max_size; i++) {
     target[i].first = 0;
-    target[i + 1].second = std::find_if(target[i].second, last,
-                                        rak::less(i * choke_queue::order_base + (choke_queue::order_base - 1),
-                                                  rak::mem_ref(&choke_queue::value_type::weight)));
+    target[i + 1].second = std::find_if(target[i].second, last, [i](auto& v) {
+      return (i * choke_queue::order_base + (choke_queue::order_base - 1)) < v.weight;
+    });
 
     if (std::distance(target[i].second, target[i + 1].second) != 0)
       weightTotal += weights[i];
@@ -593,8 +566,8 @@ choke_queue::adjust_choke_range(iterator first, iterator last,
       itr_adjust--;
 
       // if (!is_choke && !should_connection_unchoke(this, itr_adjust->first)) {
-      //   // Swap with end and continue if not done with group. Count how many?
-      //   std::iter_swap(itr_adjust, --last_adjust);
+        // Swap with end and continue if not done with group. Count how many?
+        // std::iter_swap(itr_adjust, --last_adjust);
 
       //   if (first_adjust == (itr - 1)->second)
       //     skipped++;
@@ -651,21 +624,104 @@ void
 calculate_upload_unchoke(choke_queue::iterator first, choke_queue::iterator last) {
   while (first != last) {
     if (first->connection->is_down_local_unchoked()) {
-      uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate();
+      uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate() / 16;
 
       // If the peer transmits at less than 1KB, we should consider it
       // to be a rather stingy peer, and should look for new ones.
 
-      if (downloadRate < 1000)
+      if (downloadRate < 2048 / 16)
         first->weight = downloadRate;
       else
-        first->weight = 2 * choke_queue::order_base + downloadRate;
+        first->weight = 3 * choke_queue::order_base + downloadRate;
 
     } else {
       // This will be our optimistic unchoke queue, should be
       // semi-random. Give lower weights to known stingy peers.
+      int order = 1 + first->connection->peer_info()->is_preferred();
 
-      first->weight = 1 * choke_queue::order_base + ::random() % (1 << 10);
+      first->weight = order * choke_queue::order_base + ::random() % (1 << 10);
+    }
+
+    first++;
+  }
+}
+
+// Improved heuristics intended for seeding.
+
+void
+calculate_upload_choke_seed(choke_queue::iterator first, choke_queue::iterator last) {
+  while (first != last) {
+    int order = 1; // + first->connection->peer_info()->is_preferred();
+    uint32_t upload_rate = first->connection->peer_chunks()->upload_throttle()->rate()->rate() / 16;
+
+    first->weight = order * choke_queue::order_base - 1 - upload_rate;
+    first++;
+  }
+}
+
+void
+calculate_upload_unchoke_seed(choke_queue::iterator first, choke_queue::iterator last) {
+  while (first != last) {
+    int order = first->connection->peer_info()->is_preferred();
+
+    first->weight = order * choke_queue::order_base + ::random() % (1 << 10);
+    first++;
+  }
+}
+
+//
+// New leeching choke algorithm that 
+//
+
+// Order 0: Normal
+// Order 1: No choking of newly unchoked peers.
+void
+calculate_choke_upload_leech_experimental(choke_queue::iterator first, choke_queue::iterator last) {
+  while (first != last) {
+    // Don't choke a peer that hasn't had time to unchoke us.
+    if (rak::timer(first->connection->up_choke()->time_last_choke()) + rak::timer::from_seconds(50) > cachedTime) {
+      first->weight = 1 * choke_queue::order_base;
+      first++;
+      continue;
+    }
+
+    // Preferred peers will get 4 times higher weight.
+    int multiplier = 1 + 3 * first->connection->peer_info()->is_preferred();
+
+    uint32_t download_rate = first->connection->peer_chunks()->download_throttle()->rate()->rate() / 64;
+    uint32_t upload_rate   = first->connection->peer_chunks()->upload_throttle()->rate()->rate() / (64 * 4);
+
+    first->weight = choke_queue::order_base - 1 - (download_rate + upload_rate) * multiplier;
+    first++;
+  }
+}
+
+// Order 0: Optimistic unchokes.
+// Order 1: Normal unchokes.
+void
+calculate_unchoke_upload_leech_experimental(choke_queue::iterator first, choke_queue::iterator last) {
+  while (first != last) {
+    // Consider checking for is_down_remote_unchoked().
+    if (first->connection->is_down_local_unchoked()) {
+      int multiplier = 1 + 3 * first->connection->peer_info()->is_preferred();
+
+      uint32_t download_rate = first->connection->peer_chunks()->download_throttle()->rate()->rate() / 64;
+
+      first->weight = choke_queue::order_base + download_rate * multiplier;
+
+    } else {
+      // This will be our optimistic unchoke queue, should be
+      // semi-random. Give lower weights to known stingy peers and
+      // higher weight for preferred ones.
+      int base = (1 << 10);
+
+      if (first->connection->peer_info()->is_preferred())
+        base *= 4;
+
+      // else if (<peer is stingy>)
+      //   base /= 8;
+
+      first->weight = ::random() % base;
     }
 
     first++;
@@ -678,7 +734,7 @@ void
 calculate_download_choke(choke_queue::iterator first, choke_queue::iterator last) {
   while (first != last) {
     // Very crude version for now.
-    uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate();
+    uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate() / 16;
     first->weight = choke_queue::order_base - 1 - downloadRate;
 
     first++;
@@ -689,7 +745,7 @@ void
 calculate_download_unchoke(choke_queue::iterator first, choke_queue::iterator last) {
   while (first != last) {
     // Very crude version for now.
-    uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate();
+    uint32_t downloadRate = first->connection->peer_chunks()->download_throttle()->rate()->rate() / 16;
     first->weight = downloadRate;
 
     first++;
@@ -697,10 +753,10 @@ calculate_download_unchoke(choke_queue::iterator first, choke_queue::iterator la
 }
 
 choke_queue::heuristics_type choke_queue::m_heuristics_list[HEURISTICS_MAX_SIZE] = {
-  { &calculate_upload_choke,      &calculate_upload_unchoke,      { 1, 1, 1, 1 }, { 1, 3, 9, 0 } },
-  { &calculate_upload_choke,      &calculate_upload_unchoke,      { 1, 1, 1, 1 }, { 1, 3, 9, 0 } },
-  { &calculate_download_choke,    &calculate_download_unchoke,    { 1, 1, 1, 1 }, { 1, 1, 1, 1 } },
-  { &calculate_download_choke,    &calculate_download_unchoke,    { 1, 1, 1, 1 }, { 1, 1, 1, 1 } },
+  { &calculate_upload_choke,                    &calculate_upload_unchoke,      { 1, 1, 1, 1 }, { 1, 3, 6, 9 } },
+  { &calculate_upload_choke_seed,               &calculate_upload_unchoke_seed, { 1, 1, 1, 1 }, { 1, 3, 6, 9 } },
+  { &calculate_choke_upload_leech_experimental, &calculate_unchoke_upload_leech_experimental, { 32, 1, 1, 1 }, { 1, 6, 8, 16 } },
+  { &calculate_download_choke,                  &calculate_download_unchoke,    { 1, 1, 1, 1 }, { 1, 1, 1, 1 } },
 };
 
 }
