@@ -1,47 +1,9 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
 #include <functional>
-#include lt_tr1_functional
 #include <limits>
 #include <numeric>
-#include <rak/functional.h>
 
 #include "torrent/exceptions.h"
 #include "torrent/download/choke_group.h"
@@ -52,6 +14,11 @@
 #include "choke_queue.h"
 #include "resource_manager.h"
 
+#define LT_LOG_THIS(log_fmt, ...)                                       \
+  lt_log_print_subsystem(LOG_TORRENT_INFO, "resource_manager", log_fmt, __VA_ARGS__);
+#define LT_LOG_ITR(log_fmt, ...)                                        \
+  lt_log_print_info(LOG_TORRENT_INFO, itr->download()->info(), "resource_manager", log_fmt, __VA_ARGS__);
+
 namespace torrent {
 
 const Rate* resource_manager_entry::up_rate() const { return m_download->info()->up_rate(); }
@@ -72,7 +39,7 @@ ResourceManager::~ResourceManager() {
   if (m_currentlyDownloadUnchoked != 0)
     throw internal_error("ResourceManager::~ResourceManager() called but m_currentlyDownloadUnchoked != 0.");
 
-  std::for_each(choke_base_type::begin(), choke_base_type::end(), rak::call_delete<choke_group>());
+  std::for_each(choke_base_type::begin(), choke_base_type::end(), [](choke_group* g) { delete g; });
 }
 
 // If called directly ensure a valid group has been selected.
@@ -108,8 +75,9 @@ ResourceManager::update_group_iterators() {
 
   while (group_itr != choke_base_type::end()) {
     (*group_itr)->set_first(&*entry_itr);
-    entry_itr = std::find_if(entry_itr, end(), rak::less(std::distance(choke_base_type::begin(), group_itr),
-                                                         std::mem_fun_ref(&value_type::group)));
+    entry_itr = std::find_if(entry_itr, end(), [group_itr, this](value_type v) {
+      return (std::distance(choke_base_type::begin(), group_itr)) < v.group();
+    });
     (*group_itr)->set_last(&*entry_itr);
     group_itr++;
   }
@@ -124,8 +92,9 @@ ResourceManager::validate_group_iterators() {
     if ((*group_itr)->first() != &*entry_itr)
       throw internal_error("ResourceManager::receive_tick() invalid first iterator.");
 
-    entry_itr = std::find_if(entry_itr, end(), rak::less(std::distance(choke_base_type::begin(), group_itr),
-                                                         std::mem_fun_ref(&value_type::group)));
+    entry_itr = std::find_if(entry_itr, end(), [group_itr, this](value_type v) {
+      return (std::distance(choke_base_type::begin(), group_itr)) < v.group();
+    });
     if ((*group_itr)->last() != &*entry_itr)
       throw internal_error("ResourceManager::receive_tick() invalid last iterator.");
 
@@ -135,7 +104,7 @@ ResourceManager::validate_group_iterators() {
 
 void
 ResourceManager::erase(DownloadMain* d) {
-  iterator itr = std::find_if(begin(), end(), rak::equal(d, std::mem_fun_ref(&value_type::download)));
+  auto itr = std::find_if(begin(), end(), [d](value_type e) { return d == e.download(); });
 
   if (itr == end())
     throw internal_error("ResourceManager::erase() itr == end().");
@@ -154,8 +123,8 @@ ResourceManager::erase(DownloadMain* d) {
 void
 ResourceManager::push_group(const std::string& name) {
   if (name.empty() ||
-      std::find_if(choke_base_type::begin(), choke_base_type::end(),
-                   rak::equal(name, std::mem_fun(&choke_group::name))) != choke_base_type::end())
+      std::any_of(choke_base_type::begin(), choke_base_type::end(),
+                  [name](choke_group* g) { return name == g->name(); }))
     throw input_error("Duplicate name for choke group.");
 
   choke_base_type::push_back(new choke_group());
@@ -177,12 +146,12 @@ ResourceManager::push_group(const std::string& name) {
 
 ResourceManager::iterator
 ResourceManager::find(DownloadMain* d) {
-  return std::find_if(begin(), end(), rak::equal(d, std::mem_fun_ref(&value_type::download)));
+  return std::find_if(begin(), end(), [d](value_type e) { return d == e.download(); });
 }
 
 ResourceManager::iterator
 ResourceManager::find_throw(DownloadMain* d) {
-  iterator itr = std::find_if(begin(), end(), rak::equal(d, std::mem_fun_ref(&value_type::download)));
+  auto itr = find(d);
 
   if (itr == end())
     throw input_error("Could not find download in resource manager.");
@@ -192,7 +161,7 @@ ResourceManager::find_throw(DownloadMain* d) {
 
 ResourceManager::iterator
 ResourceManager::find_group_end(uint16_t group) {
-  return std::find_if(begin(), end(), rak::less(group, std::mem_fun_ref(&value_type::group)));
+  return std::find_if(begin(), end(), [group](value_type v) { return group < v.group(); });
 }
 
 choke_group*
@@ -205,8 +174,7 @@ ResourceManager::group_at(uint16_t grp) {
 
 choke_group*
 ResourceManager::group_at_name(const std::string& name) {
-  choke_base_type::iterator itr = std::find_if(choke_base_type::begin(), choke_base_type::end(),
-                                               rak::equal(name, std::mem_fun(&choke_group::name)));
+  auto itr = std::find_if(choke_base_type::begin(), choke_base_type::end(), [name](choke_group* g) { return name == g->name(); });
 
   if (itr == choke_base_type::end())
     throw input_error("Choke group not found.");
@@ -216,8 +184,8 @@ ResourceManager::group_at_name(const std::string& name) {
 
 int
 ResourceManager::group_index_of(const std::string& name) {
-  choke_base_type::iterator itr = std::find_if(choke_base_type::begin(), choke_base_type::end(),
-                                               rak::equal(name, std::mem_fun(&choke_group::name)));
+  auto itr = std::find_if(choke_base_type::begin(), choke_base_type::end(),
+                          [name](choke_group* g) { return name == g->name(); });
 
   if (itr == choke_base_type::end())
     throw input_error("Choke group not found.");
@@ -227,6 +195,8 @@ ResourceManager::group_index_of(const std::string& name) {
 
 void
 ResourceManager::set_priority(iterator itr, uint16_t pri) {
+  LT_LOG_ITR("set priority: %" PRIu16, 0)
+
   itr->set_priority(pri);
 }
 
@@ -266,16 +236,16 @@ ResourceManager::set_group(iterator itr, uint16_t grp) {
 
 void
 ResourceManager::set_max_upload_unchoked(unsigned int m) {
-  if (m > (1 << 16))
-    throw input_error("Max unchoked must be between 0 and 2^16.");
+  if (m > (1 << 20))
+    throw input_error("Max unchoked must be between 0 and 2^20.");
 
   m_maxUploadUnchoked = m;
 }
 
 void
 ResourceManager::set_max_download_unchoked(unsigned int m) {
-  if (m > (1 << 16))
-    throw input_error("Max unchoked must be between 0 and 2^16.");
+  if (m > (1 << 20))
+    throw input_error("Max unchoked must be between 0 and 2^20.");
 
   m_maxDownloadUnchoked = m;
 }
@@ -284,7 +254,7 @@ ResourceManager::set_max_download_unchoked(unsigned int m) {
 // possibly multiple calls of this function.
 void
 ResourceManager::receive_upload_unchoke(int num) {
-  lt_log_print(LOG_PEER_INFO, "Upload unchoked slots adjust; currently:%u adjust:%i", m_currentlyUploadUnchoked, num);
+  LT_LOG_THIS("adjusting upload unchoked slots; current:%u adjusted:%i", m_currentlyUploadUnchoked, num);
 
   if ((int)m_currentlyUploadUnchoked + num < 0)
     throw internal_error("ResourceManager::receive_upload_unchoke(...) received an invalid value.");
@@ -294,7 +264,7 @@ ResourceManager::receive_upload_unchoke(int num) {
 
 void
 ResourceManager::receive_download_unchoke(int num) {
-  lt_log_print(LOG_PEER_INFO, "Download unchoked slots adjust; currently:%u adjust:%i", m_currentlyDownloadUnchoked, num);
+  LT_LOG_THIS("adjusting download unchoked slots; current:%u adjusted:%i", m_currentlyDownloadUnchoked, num);
 
   if ((int)m_currentlyDownloadUnchoked + num < 0)
     throw internal_error("ResourceManager::receive_download_unchoke(...) received an invalid value.");
@@ -343,7 +313,7 @@ ResourceManager::receive_tick() {
 unsigned int
 ResourceManager::total_weight() const {
   // TODO: This doesn't take into account inactive downloads.
-  return std::for_each(begin(), end(), rak::accumulate((unsigned int)0, std::mem_fun_ref(&value_type::priority))).result;
+  return std::accumulate(begin(), end(), (unsigned int)0, [](unsigned int i, auto r){ return i + r.priority(); });
 }
 
 int
@@ -388,12 +358,14 @@ ResourceManager::balance_unchoked(unsigned int weight, unsigned int max_unchoked
     std::sort(group_first, group_last, std::bind(std::less<uint32_t>(),
                                                  std::bind(&choke_group::up_requested, std::placeholders::_1),
                                                  std::bind(&choke_group::up_requested, std::placeholders::_2)));
-    lt_log_print(LOG_PEER_DEBUG, "Upload unchoked slots cycle; currently:%u adjusted:%i max_unchoked:%u", m_currentlyUploadUnchoked, change, max_unchoked);
+
+    LT_LOG_THIS("balancing upload unchoked slots; current_unchoked:%u change:%i max_unchoked:%u", m_currentlyUploadUnchoked, change, max_unchoked);
   } else {
     std::sort(group_first, group_last, std::bind(std::less<uint32_t>(),
                                                  std::bind(&choke_group::down_requested, std::placeholders::_1),
                                                  std::bind(&choke_group::down_requested, std::placeholders::_2)));
-    lt_log_print(LOG_PEER_DEBUG, "Download unchoked slots cycle; currently:%u adjusted:%i max_unchoked:%u", m_currentlyDownloadUnchoked, change, max_unchoked);
+
+    LT_LOG_THIS("balancing download unchoked slots; current_unchoked:%u change:%i max_unchoked:%u", m_currentlyDownloadUnchoked, change, max_unchoked);
   }
 
   while (group_first != group_last) {
