@@ -38,7 +38,6 @@
 
 #include <algorithm>
 #include <cstring>
-#include <rak/functional.h>
 
 #include "object.h"
 #include "object_stream.h"
@@ -150,7 +149,7 @@ Object::merge_copy(const Object& object, uint32_t skip_mask, uint32_t maxDepth)
     map_type::const_iterator srcLast = object.as_map().end();
 
     while (srcItr != srcLast) {
-      destItr = std::find_if(destItr, dest.end(), rak::less_equal(srcItr->first, rak::mem_ref(&map_type::value_type::first)));
+      destItr = std::find_if(destItr, dest.end(), [srcItr](const auto& v) { return srcItr->first <= v.first; });
 
       if (srcItr->first < destItr->first)
         // destItr remains valid and pointing to the next possible
