@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
@@ -45,14 +9,21 @@
 
 namespace torrent {
 
+constexpr int Tracker::default_min_interval;
+constexpr int Tracker::min_min_interval;
+constexpr int Tracker::max_min_interval;
+constexpr int Tracker::default_normal_interval;
+constexpr int Tracker::min_normal_interval;
+constexpr int Tracker::max_normal_interval;
+
 Tracker::Tracker(TrackerList* parent, const std::string& url, int flags) :
   m_flags(flags),
   m_parent(parent),
   m_group(0),
   m_url(url),
 
-  m_normal_interval(1800),
-  m_min_interval(600),
+  m_normal_interval(0),
+  m_min_interval(0),
 
   m_latest_event(EVENT_NONE),
   m_latest_new_peers(0),
@@ -82,7 +53,7 @@ Tracker::enable() {
     return;
 
   m_flags |= flag_enabled;
-  
+
   if (m_parent->slot_tracker_enabled())
     m_parent->slot_tracker_enabled()(this);
 }
@@ -104,7 +75,7 @@ Tracker::success_time_next() const {
   if (m_success_counter == 0)
     return 0;
 
-  return m_success_time_last + m_normal_interval;
+  return m_success_time_last + std::max(m_normal_interval, (uint32_t)min_normal_interval);
 }
 
 uint32_t
@@ -112,7 +83,10 @@ Tracker::failed_time_next() const {
   if (m_failed_counter == 0)
     return 0;
 
-  return m_failed_time_last + (5 << std::min(m_failed_counter - 1, (uint32_t)6));
+  if (m_min_interval > min_min_interval)
+    return m_failed_time_last + m_min_interval;
+
+  return m_failed_time_last + std::min(5 << std::min(m_failed_counter - 1, (uint32_t)6), min_min_interval-1);
 }
 
 std::string
