@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
@@ -41,14 +5,13 @@
 #include <cstring>
 
 #include "torrent/connection_manager.h"
+#include "torrent/download.h"
+#include "torrent/exceptions.h"
 #include "torrent/object.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
-
-#include "exceptions.h"
-#include "download.h"
-#include "log.h"
-#include "option_strings.h"
+#include "torrent/utils/log.h"
+#include "torrent/utils/option_strings.h"
 
 namespace torrent {
 
@@ -62,7 +25,7 @@ struct option_pair {
   unsigned int value;
 };
 
-option_pair option_list_connection[] = {
+option_pair option_list_connection_type[] = {
   { "leech",        Download::CONNECTION_LEECH },
   { "seed",         Download::CONNECTION_SEED },
   { "initial_seed", Download::CONNECTION_INITIAL_SEED },
@@ -124,6 +87,19 @@ option_pair option_list_tracker_mode[] = {
   { NULL, 0 }
 };
 
+const char* option_list_handshake_connection[] = {
+  "none",
+  "incoming",
+  "outgoing_normal",
+  "outgoing_encrypted",
+  "outgoing_proxy",
+  "success",
+  "dropped",
+  "failed",
+  "retry_plaintext",
+  "retry_encrypted"
+};
+
 const char* option_list_log_group[] = {
   "critical",
   "error",
@@ -131,28 +107,21 @@ const char* option_list_log_group[] = {
   "notice",
   "info",
   "debug",
-  
-  "connection_critical",
-  "connection_error",
-  "connection_warn",
-  "connection_notice",
-  "connection_info",
-  "connection_debug",
-  
+
   "dht_critical",
   "dht_error",
   "dht_warn",
   "dht_notice",
   "dht_info",
   "dht_debug",
-  
+
   "peer_critical",
   "peer_error",
   "peer_warn",
   "peer_notice",
   "peer_info",
   "peer_debug",
-  
+
   "socket_critical",
   "socket_error",
   "socket_warn",
@@ -173,14 +142,14 @@ const char* option_list_log_group[] = {
   "thread_notice",
   "thread_info",
   "thread_debug",
-  
+
   "tracker_critical",
   "tracker_error",
   "tracker_warn",
   "tracker_notice",
   "tracker_info",
   "tracker_debug",
-  
+
   "torrent_critical",
   "torrent_error",
   "torrent_warn",
@@ -190,6 +159,13 @@ const char* option_list_log_group[] = {
 
   "__non_cascading__",
 
+  "connection",
+  "connection_bind",
+  "connection_fd",
+  "connection_filter",
+  "connection_hanshake",
+  "connection_listen",
+
   "dht_all",
   "dht_manager",
   "dht_node",
@@ -202,7 +178,10 @@ const char* option_list_log_group[] = {
   "instrumentation_polling",
   "instrumentation_transfers",
 
+  "mock_calls",
+
   "peer_list_events",
+  "peer_list_address",
 
   "protocol_piece_events",
   "protocol_metadata_events",
@@ -214,6 +193,9 @@ const char* option_list_log_group[] = {
   "rpc_events",
   "rpc_dump",
 
+  "storage",
+  "system",
+
   "ui_events",
 
   NULL
@@ -230,7 +212,7 @@ const char* option_list_tracker_event[] = {
 };
 
 option_pair* option_pair_lists[OPTION_START_COMPACT] = {
-  option_list_connection,
+  option_list_connection_type,
   option_list_heuristics,
   option_list_heuristics_download,
   option_list_heuristics_upload,
@@ -244,6 +226,7 @@ option_pair* option_pair_lists[OPTION_START_COMPACT] = {
   { sizeof(single_name) / sizeof(const char*) - 1, single_name }
 
 option_single option_single_lists[OPTION_SINGLE_SIZE] = {
+  OPTION_SINGLE_ENTRY(option_list_handshake_connection),
   OPTION_SINGLE_ENTRY(option_list_log_group),
   OPTION_SINGLE_ENTRY(option_list_tracker_event),
 };
@@ -267,11 +250,11 @@ option_find_string(option_enum opt_enum, const char* name) {
     } while (*++itr != NULL);
   }
 
-  throw input_error("Invalid option name.");  
+  throw input_error("Invalid option name.");
 }
 
 const char*
-option_as_string(option_enum opt_enum, unsigned int value) {
+option_to_string(option_enum opt_enum, unsigned int value, const char* not_found) {
   if (opt_enum < OPTION_START_COMPACT) {
     option_pair* itr = option_pair_lists[opt_enum];
   
@@ -285,7 +268,27 @@ option_as_string(option_enum opt_enum, unsigned int value) {
       return option_single_lists[opt_enum - OPTION_START_COMPACT].name[value];
   }
 
-  throw input_error("Invalid option value.");  
+  return not_found;
+}
+
+const char*
+option_to_string_or_throw(option_enum opt_enum, unsigned int value, const char* not_found) {
+  const char* result = option_to_string(opt_enum, value, NULL);
+
+  if (result == NULL)
+    throw input_error(not_found);
+  else
+    return result;
+}
+
+const char*
+option_as_string(option_enum opt_enum, unsigned int value) {
+  const char* result = option_to_string(opt_enum, value, NULL);
+
+  if (result == NULL)
+    throw input_error("Invalid option value.");
+  else
+    return result;
 }
 
 torrent::Object
@@ -296,12 +299,13 @@ option_list_strings(option_enum opt_enum) {
     option_pair* itr = option_pair_lists[opt_enum];
 
     while (itr->name != NULL)
-      result.push_back(std::string(itr++->name));
+      result.emplace_back(std::string(itr++->name));
 
   } else if (opt_enum < OPTION_MAX_SIZE) {
     const char** itr = option_single_lists[opt_enum - OPTION_START_COMPACT].name;
-  
-    while (*itr != NULL) result.push_back(std::string(*itr++));
+
+    while (*itr != NULL)
+      result.emplace_back(std::string(*itr++));
   }
 
   return Object::from_list(result);
