@@ -1,7 +1,7 @@
 #include "config.h"
 
+#include <functional>
 #include <iostream>
-#include lt_tr1_functional
 
 #include "rak/priority_queue_default.h"
 
@@ -146,8 +146,8 @@ tracker_controller_test::test_single_failure() {
   TEST_SINGLE_FAILURE_TIMEOUT(40);
   TEST_SINGLE_FAILURE_TIMEOUT(80);
   TEST_SINGLE_FAILURE_TIMEOUT(160);
-  TEST_SINGLE_FAILURE_TIMEOUT(320);
-  TEST_SINGLE_FAILURE_TIMEOUT(320);
+  TEST_SINGLE_FAILURE_TIMEOUT(299);
+  TEST_SINGLE_FAILURE_TIMEOUT(299);
 
   // TODO: Test with cachedTime not rounded to second.
 
@@ -334,7 +334,7 @@ tracker_controller_test::test_multiple_failure() {
   TEST_MULTI3_IS_BUSY("00100", "00100");
   CPPUNIT_ASSERT(tracker_1_0->trigger_success());
 
-  CPPUNIT_ASSERT(test_goto_next_timeout(&tracker_controller, tracker_0_0->normal_interval()));
+  CPPUNIT_ASSERT(test_goto_next_timeout(&tracker_controller, tracker_1_0->normal_interval()));
   TEST_MULTI3_IS_BUSY("10000", "10000");
   CPPUNIT_ASSERT(tracker_0_0->trigger_failure());
   TEST_MULTI3_IS_BUSY("01000", "01000");
